@@ -9,7 +9,10 @@ require Locale::Utils::PlaceholderMaketext;
 
 my $obj = Locale::Utils::PlaceholderMaketext->new;
 
-() = print
+() = print {*STDOUT}
+    Locale::Utils::PlaceholderMaketext
+        ->maketext_to_gettext('foo [_1] bar'),
+    "\n",
     $obj->maketext_to_gettext('foo [_1] bar'),
     "\n",
     $obj->maketext_to_gettext('~~ % foo ~[[_1]~] bar'),
@@ -19,12 +22,13 @@ my $obj = Locale::Utils::PlaceholderMaketext->new;
     $obj->maketext_to_gettext('bar [*,_2,singluar,plural] baz'),
     "\n";
 
-# $Id: 01_maketext_to_gettext.pl 397 2012-04-24 15:15:49Z steffenw $
+# $Id: 01_maketext_to_gettext.pl 406 2013-10-22 16:28:13Z steffenw $
 
 __END__
 
 Output:
 
+foo %1 bar
 foo %1 bar
 ~ %% foo [%1] bar
 foo %1 bar %quant(%2,singluar,plural,zero) baz
